EXPORTS
	__21TestMsvOperationTimerP12CConsoleBaseP13CMsvOperationR5RTest @ 1 NONAME ; TestMsvOperationTimer::TestMsvOperationTimer(CConsoleBase *, CMsvOperation *, RTest &)
	AddItemL__14CScriptSectionRC7TDesC16T1 @ 2 NONAME ; CScriptSection::AddItemL(TDesC16 const &, TDesC16 const &)
	AfterReq__10CTestTimerG27TTimeIntervalMicroSeconds32R14TRequestStatus @ 3 NONAME ; CTestTimer::AfterReq(TTimeIntervalMicroSeconds32, TRequestStatus &)
	AppendScheduleTimeL__13CMsvTestUtilslR6TDes16 @ 4 NONAME ; CMsvTestUtils::AppendScheduleTimeL(long, TDes16 &)
	AppendText__10CTestUtilsRC7TDesC16R6TDes16i @ 5 NONAME ; CTestUtils::AppendText(TDesC16 const &, TDes16 &, int)
	AppendToMenuL__10CTestUtilsRC7TDesC16 @ 6 NONAME ; CTestUtils::AppendToMenuL(TDesC16 const &)
	CleanMessageFolderL__13CMsvTestUtils @ 7 NONAME ; CMsvTestUtils::CleanMessageFolderL(void)
	ClearLogL__10CTestUtilsRC10CLogFilter @ 8 NONAME ; CTestUtils::ClearLogL(CLogFilter const &)
	ClearScreen__10CTestUtilsi @ 9 NONAME ; CTestUtils::ClearScreen(int)
	ConstructL__10CTestUtils @ 10 NONAME ; CTestUtils::ConstructL(void)
	ConstructL__13CMsvTestUtilsUi @ 11 NONAME ; CMsvTestUtils::ConstructL(unsigned int)
	ConstructL__21TestMsvOperationTimer @ 12 NONAME ; TestMsvOperationTimer::ConstructL(void)
	CopyLC__14CScriptSection @ 13 NONAME ; CScriptSection::CopyLC(void)
	CreateAllTestDirectories__10CTestUtils @ 14 NONAME ; CTestUtils::CreateAllTestDirectories(void)
	CreateAllTestDirectories__13CMsvTestUtils @ 15 NONAME ; CMsvTestUtils::CreateAllTestDirectories(void)
	CreateContactL__10CTestUtilsRC7TDesC16N31i @ 16 NONAME ; CTestUtils::CreateContactL(TDesC16 const &, TDesC16 const &, TDesC16 const &, TDesC16 const &, int)
	CreateRegistryObjectAndControlL__13CMsvTestUtils @ 17 NONAME ; CMsvTestUtils::CreateRegistryObjectAndControlL(void)
	CreateServerMtmRegL__13CMsvTestUtilsG4TUidRC7TDesC16RC15TMsvTestDllInfoN33T1T2 @ 18 NONAME ; CMsvTestUtils::CreateServerMtmRegL(TUid, TDesC16 const &, TMsvTestDllInfo const &, TMsvTestDllInfo const &, TMsvTestDllInfo const &, TMsvTestDllInfo const &, TUid, TDesC16 const &)
	CreateServiceL__13CMsvTestUtilsG4TUidii @ 19 NONAME ; CMsvTestUtils::CreateServiceL(TUid, int, int)
	DeleteContactsFileL__10CTestUtils @ 20 NONAME ; CTestUtils::DeleteContactsFileL(void)
	DeleteItemsL__14CScriptSectionRC7TDesC16 @ 21 NONAME ; CScriptSection::DeleteItemsL(TDesC16 const &)
	DeleteServiceL__13CMsvTestUtilsG4TUid @ 22 NONAME ; CMsvTestUtils::DeleteServiceL(TUid)
	DisplayChildL__13CMsvTestUtilsRC9TMsvEntry @ 23 NONAME ; CMsvTestUtils::DisplayChildL(TMsvEntry const &)
	DisplayFile__10CTestUtilsRC7TDesC16 @ 24 NONAME ; CTestUtils::DisplayFile(TDesC16 const &)
	DisplayLogL__10CTestUtilsRC10CLogFilteri @ 25 NONAME ; CTestUtils::DisplayLogL(CLogFilter const &, int)
	DisplayMenu__10CTestUtilsRC7TDesC16iiii @ 26 NONAME ; CTestUtils::DisplayMenu(TDesC16 const &, int, int, int, int)
	DoBuf__10CTestUtilsR5TDes8RC7TDesC16RC6TDesC8 @ 27 NONAME ; CTestUtils::DoBuf(TDes8 &, TDesC16 const &, TDesC8 const &)
	DoBuf__10CTestUtilsR5TDes8RC7TDesC16T2 @ 28 NONAME ; CTestUtils::DoBuf(TDes8 &, TDesC16 const &, TDesC16 const &)
	DoCancel__11CTestActive @ 29 NONAME ; CTestActive::DoCancel(void)
	DoCancel__21TestMsvOperationTimer @ 30 NONAME ; TestMsvOperationTimer::DoCancel(void)
	FindChildrenL__13CMsvTestUtilslRCt4TBuf1i256ii @ 31 NONAME ; CMsvTestUtils::FindChildrenL(long, TBuf<256> const &, int, int)
	FindChildrenL__13CMsvTestUtilslii @ 32 NONAME ; CMsvTestUtils::FindChildrenL(long, int, int)
	FindPos__C24CMsvConfigEntrySelectionRC7TDesC16 @ 33 NONAME ; CMsvConfigEntrySelection::FindPos(TDesC16 const &) const
	Find__C24CMsvConfigEntrySelectionRC7TDesC16 @ 34 NONAME ; CMsvConfigEntrySelection::Find(TDesC16 const &) const
	GetNextWord__11CScriptFileR6TLex16G5TCharR7TPtrC16 @ 35 NONAME ; CScriptFile::GetNextWord(TLex16 &, TChar, TPtrC16 &)
	GetNextWord__11CScriptFileR6TLex16G5TCharRi @ 36 NONAME ; CScriptFile::GetNextWord(TLex16 &, TChar, int &)
	GoClientSideL__13CMsvTestUtils @ 37 NONAME ; CMsvTestUtils::GoClientSideL(void)
	GoServerSideL__13CMsvTestUtils @ 38 NONAME ; CMsvTestUtils::GoServerSideL(void)
	InstallMtmGroupL__13CMsvTestUtilsRC7TDesC16 @ 39 NONAME ; CMsvTestUtils::InstallMtmGroupL(TDesC16 const &)
	InstantiateClientMtmL__13CMsvTestUtilsG4TUidl @ 40 NONAME ; CMsvTestUtils::InstantiateClientMtmL(TUid, long)
	InstantiateServerMtmL__13CMsvTestUtilsG4TUidl @ 41 NONAME ; CMsvTestUtils::InstantiateServerMtmL(TUid, long)
	Int__C15TMsvConfigEntry @ 42 NONAME ; TMsvConfigEntry::Int(void) const
	IssueRequest__21TestMsvOperationTimer @ 43 NONAME ; TestMsvOperationTimer::IssueRequest(void)
	ItemValueLC__11CScriptFileR10CTestUtilsRC7TDesC16N42 @ 44 NONAME ; CScriptFile::ItemValueLC(CTestUtils &, TDesC16 const &, TDesC16 const &, TDesC16 const &, TDesC16 const &, TDesC16 const &)
	ItemValueL__11CScriptFileR10CTestUtilsRC7TDesC16N32i @ 45 NONAME ; CScriptFile::ItemValueL(CTestUtils &, TDesC16 const &, TDesC16 const &, TDesC16 const &, TDesC16 const &, int)
	ItemValue__11CScriptFileRC7TDesC16N21 @ 46 NONAME ; CScriptFile::ItemValue(TDesC16 const &, TDesC16 const &, TDesC16 const &)
	ItemValue__11CScriptFileRC7TDesC16T1i @ 47 NONAME ; CScriptFile::ItemValue(TDesC16 const &, TDesC16 const &, int)
	ItemValue__14CScriptSectionRC7TDesC16T1 @ 48 NONAME ; CScriptSection::ItemValue(TDesC16 const &, TDesC16 const &)
	ItemValue__14CScriptSectionRC7TDesC16i @ 49 NONAME ; CScriptSection::ItemValue(TDesC16 const &, int)
	Item__14CScriptSectionRC7TDesC16 @ 50 NONAME ; CScriptSection::Item(TDesC16 const &)
	ListChildrenL__13CMsvTestUtilsR5RFileR4CDirRiT3ii @ 51 NONAME ; CMsvTestUtils::ListChildrenL(RFile &, CDir &, int &, int &, int, int)
	MenuCount__C10CTestUtils @ 52 NONAME ; CTestUtils::MenuCount(void) const
	NavigateMessageStoreL__13CMsvTestUtilsl @ 53 NONAME ; CMsvTestUtils::NavigateMessageStoreL(long)
	NewLC__11CScriptFileR10CTestUtilsRC7TDesC16 @ 54 NONAME ; CScriptFile::NewLC(CTestUtils &, TDesC16 const &)
	NewLC__11CScriptFileR10CTestUtilsRC7TDesC16T2 @ 55 NONAME ; CScriptFile::NewLC(CTestUtils &, TDesC16 const &, TDesC16 const &)
	NewLC__14CScriptSectionRC7TDesC16 @ 56 NONAME ; CScriptSection::NewLC(TDesC16 const &)
	NewLC__14CScriptSectionRC7TDesC16R14CScriptSection @ 57 NONAME ; CScriptSection::NewLC(TDesC16 const &, CScriptSection &)
	NewLC__18CScriptSectionItemR14CScriptSectionRC7TDesC16T2 @ 58 NONAME ; CScriptSectionItem::NewLC(CScriptSection &, TDesC16 const &, TDesC16 const &)
	NewLC__21TestMsvOperationTimerP12CConsoleBaseP13CMsvOperationR5RTest @ 59 NONAME ; TestMsvOperationTimer::NewLC(CConsoleBase *, CMsvOperation *, RTest &)
	NewL__10CTestTimer @ 60 NONAME ; CTestTimer::NewL(void)
	NewL__24CMsvConfigEntrySelectionR3RFsRC7TDesC16 @ 61 NONAME ; CMsvConfigEntrySelection::NewL(RFs &, TDesC16 const &)
	NewL__24CTestUtilsWatcherStarterR14TRequestStatusG27TTimeIntervalMicroSeconds32i @ 62 NONAME ; CTestUtilsWatcherStarter::NewL(TRequestStatus &, TTimeIntervalMicroSeconds32, int)
	NewL__24CTestUtilsWatcherStarteri @ 63 NONAME ; CTestUtilsWatcherStarter::NewL(int)
	PrintHex__10CTestUtilsRC6TDesC8 @ 64 NONAME ; CTestUtils::PrintHex(TDesC8 const &)
	PrintHex__10CTestUtilsRC7TDesC16 @ 65 NONAME ; CTestUtils::PrintHex(TDesC16 const &)
	Printf__10CTestUtilsGt11TRefByValue1ZC7TDesC16e @ 66 NONAME ; CTestUtils::Printf(TRefByValue<TDesC16 const>,...)
	ReadFileLC__10CTestUtilsRC7TDesC16 @ 67 NONAME ; CTestUtils::ReadFileLC(TDesC16 const &)
	ReadScriptL__11CScriptFileRC7TDesC16 @ 68 NONAME ; CScriptFile::ReadScriptL(TDesC16 const &)
	RemoveRichtextFormating__10CTestUtilsR6TDes16 @ 69 NONAME ; CTestUtils::RemoveRichtextFormating(TDes16 &)
	ReplaceItemL__14CScriptSectionRC7TDesC16T1 @ 70 NONAME ; CScriptSection::ReplaceItemL(TDesC16 const &, TDesC16 const &)
	ReplaceLC__11CScriptFileRC7TDesC16N21 @ 71 NONAME ; CScriptFile::ReplaceLC(TDesC16 const &, TDesC16 const &, TDesC16 const &)
	ReplaceL__11CScriptFileRC7TDesC16T1RP7HBufC16 @ 72 NONAME ; CScriptFile::ReplaceL(TDesC16 const &, TDesC16 const &, HBufC16 *&)
	ResetMenu__10CTestUtils @ 73 NONAME ; CTestUtils::ResetMenu(void)
	Reset__13CMsvTestUtils @ 74 NONAME ; CMsvTestUtils::Reset(void)
	ResolveFile__10CTestUtilsRC7TDesC16T1R6TParse @ 75 NONAME ; CTestUtils::ResolveFile(TDesC16 const &, TDesC16 const &, TParse &)
	ResolveLogFile__10CTestUtilsRC7TDesC16R6TParse @ 76 NONAME ; CTestUtils::ResolveLogFile(TDesC16 const &, TParse &)
	RunAuto__C10CTestUtils @ 77 NONAME ; CTestUtils::RunAuto(void) const
	RunL__10CTestTimer @ 78 NONAME ; CTestTimer::RunL(void)
	RunL__11CTestActive @ 79 NONAME ; CTestActive::RunL(void)
	RunL__21TestMsvOperationTimer @ 80 NONAME ; TestMsvOperationTimer::RunL(void)
	ScheduleTime__13CMsvTestUtilslR5TTimeT2R9TTaskInfo @ 81 NONAME ; CMsvTestUtils::ScheduleTime(long, TTime &, TTime &, TTaskInfo &)
	ServiceIdL__13CMsvTestUtilsG4TUidRlP18CMsvEntrySelection @ 82 NONAME ; CMsvTestUtils::ServiceIdL(TUid, long &, CMsvEntrySelection *)
	SetFolderType__13CMsvTestUtilsR9TMsvEntryR7TPtrC16 @ 83 NONAME ; CMsvTestUtils::SetFolderType(TMsvEntry &, TPtrC16 &)
	SetLogToConsole__10CTestUtilsi @ 84 NONAME ; CTestUtils::SetLogToConsole(int)
	SetLogToFile__10CTestUtilsi @ 85 NONAME ; CTestUtils::SetLogToFile(int)
	SetNameL__10CTestUtilsR12CContactItemG4TUidRC7TDesC16i @ 86 NONAME ; CTestUtils::SetNameL(CContactItem &, TUid, TDesC16 const &, int)
	SetRunAuto__10CTestUtilsi @ 87 NONAME ; CTestUtils::SetRunAuto(int)
	Set__15TMsvConfigEntryRC7TDesC16 @ 88 NONAME ; TMsvConfigEntry::Set(TDesC16 const &)
	SpecifyLogsDir__13CMsvTestUtilsRCt4TBuf1i256 @ 89 NONAME ; CMsvTestUtils::SpecifyLogsDir(TBuf<256> const &)
	SpecifyRfc822Dir__13CMsvTestUtilsRCt4TBuf1i256 @ 90 NONAME ; CMsvTestUtils::SpecifyRfc822Dir(TBuf<256> const &)
	StartL__11CTestActive @ 91 NONAME ; CTestActive::StartL(void)
	TestFinish__10CTestUtilsii @ 92 NONAME ; CTestUtils::TestFinish(int, int)
	TestHarnessCompleted__10CTestUtils @ 93 NONAME ; CTestUtils::TestHarnessCompleted(void)
	TestHarnessFailed__10CTestUtilsi @ 94 NONAME ; CTestUtils::TestHarnessFailed(int)
	TestStart__10CTestUtilsi @ 95 NONAME ; CTestUtils::TestStart(int)
	TestStart__10CTestUtilsiRC7TDesC16 @ 96 NONAME ; CTestUtils::TestStart(int, TDesC16 const &)
	Version__C15TMsvConfigEntry @ 97 NONAME ; TMsvConfigEntry::Version(void) const
	WriteBodyDataL__13CMsvTestUtilslRCt4TBuf1i256R9CMsvStorei @ 98 NONAME ; CMsvTestUtils::WriteBodyDataL(long, TBuf<256> const &, CMsvStore &, int)
	WriteComment__10CTestUtilsRC7TDesC16 @ 99 NONAME ; CTestUtils::WriteComment(TDesC16 const &)
	WriteFileDataL__13CMsvTestUtilslRCt4TBuf1i256T2i @ 100 NONAME ; CMsvTestUtils::WriteFileDataL(long, TBuf<256> const &, TBuf<256> const &, int)
	WriteToFileL__10CTestUtilsR5RFileR6TDesC8 @ 101 NONAME ; CTestUtils::WriteToFileL(RFile &, TDesC8 &)
	WriteToFileL__10CTestUtilsR5RFileRC7TDesC16 @ 102 NONAME ; CTestUtils::WriteToFileL(RFile &, TDesC16 const &)
	"_._10CTestUtils" @ 103 NONAME ; CTestUtils::~CTestUtils(void)
	"_._11CScriptFile" @ 104 NONAME ; CScriptFile::~CScriptFile(void)
	"_._11CTestActive" @ 105 NONAME ; CTestActive::~CTestActive(void)
	"_._13CMsvTestUtils" @ 106 NONAME ; CMsvTestUtils::~CMsvTestUtils(void)
	"_._14CScriptSection" @ 107 NONAME ; CScriptSection::~CScriptSection(void)
	"_._18CScriptSectionItem" @ 108 NONAME ; CScriptSectionItem::~CScriptSectionItem(void)
	"_._24CTestUtilsWatcherStarter" @ 109 NONAME ; CTestUtilsWatcherStarter::~CTestUtilsWatcherStarter(void)
	__10CTestTimer @ 110 NONAME ; CTestTimer::CTestTimer(void)
	__10CTestUtilsR5RTest @ 111 NONAME ; CTestUtils::CTestUtils(RTest &)
	__11CTestActive @ 112 NONAME ; CTestActive::CTestActive(void)
	__13CMsvTestUtilsR5RTest @ 113 NONAME ; CMsvTestUtils::CMsvTestUtils(RTest &)
	AddItemIfNotExistL__14CScriptSectionRC7TDesC16T1 @ 114 NONAME ; CScriptSection::AddItemIfNotExistL(TDesC16 const &, TDesC16 const &)
	OpenResourceFileL__10CTestUtilsRC7TDesC16R13RResourceFile @ 115 NONAME ; CTestUtils::OpenResourceFileL(TDesC16 const &, RResourceFile &)
	ReadResourceStringL__10CTestUtilsR13RResourceFileiR6TDes16 @ 116 NONAME ; CTestUtils::ReadResourceStringL(RResourceFile &, int, TDes16 &)
	ReadResourceStringL__10CTestUtilsRC7TDesC16iR6TDes16 @ 117 NONAME ; CTestUtils::ReadResourceStringL(TDesC16 const &, int, TDes16 &)
	CopyToSimTsyConfigFileL__10CTestUtilsR3RFsRC7TDesC16 @ 118 NONAME R3UNUSED ; CTestUtils::CopyToSimTsyConfigFileL(RFs &, TDesC16 const &)
	SetSimTsyTestNumberL__10CTestUtilsi @ 119 NONAME R3UNUSED ; CTestUtils::SetSimTsyTestNumberL(int)
	SeekLogFile__10CTestUtils5TSeekRi @ 120 NONAME R3UNUSED ; CTestUtils::SeekLogFile(TSeek, int &)

